RelatedInformation class sealed

Represents related information for a MarkerData, allowing navigation to other parts of the code.

Annotations
  • @freezed

Constructors

RelatedInformation({required Uri resource, required Range range, required String message})
Creates a related information object.
const
factory
RelatedInformation.fromJson(Map<String, dynamic> json)
Creates a RelatedInformation object from a JSON map.
factory

Properties

copyWith → $RelatedInformationCopyWith<RelatedInformation>
Create a copy of RelatedInformation with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The message to display for this piece of information.
no setterinherited
range Range
The range within the resource to highlight.
no setterinherited
resource Uri
The URI of the resource to link to.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the related information to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited